Demo
====================

This module contains the Demo class, which is used to parse and hold demo file data.

awpy.demo
------------------------------

.. automodule:: awpy.demo
   :members:
   :undoc-members:
   :show-inheritance: